import React, { Component, ComponentLifecycle } from 'react';
declare type ComponentDidCatch = ComponentLifecycle<{}, {}>["componentDidCatch"];
export interface ErrorBoundaryProps {
    /**
     * Render Component when the ErrorBoundary catches an error.
     * You can custom ErrorBoundary component.
     */
    renderBoundary: (error: any) => React.ReactNode | JSX.Element;
    /**
     * Gets called when the ErrorBoundary catches an error.
     */
    onDidCatch: NonNullable<ComponentDidCatch>;
    children?: React.ReactNode | JSX.Element;
}
/**
 * Internal ErrorBoundary state.
 */
export interface ErrorBoundaryState {
    hasError: boolean;
    error: any;
}
/**
 * ErrorBoundary class
 * Catches errors using lifecycle methods and renders fallback ui using children or renderBoundary props.
 */
export declare class ErrorBoundary extends Component<ErrorBoundaryProps, ErrorBoundaryState> {
    constructor(props: ErrorBoundaryProps);
    static getDerivedStateFromError(error: any): {
        hasError: boolean;
        error: any;
    };
    componentDidCatch(...args: Parameters<NonNullable<ComponentDidCatch>>): void;
    render(): {} | null | undefined;
}
export {};
